@@ -109,7 +109,7 @@ impl Candlestick for BithumbWSClient {
 
 panic_l3_orderbook!(BithumbWSClient);
 
-define_client!(
+impl_new_constructor!(
     BithumbWSClient,
     EXCHANGE_NAME,
     WEBSOCKET_URL,
@@ -118,3 +118,4 @@ define_client!(
     Some(CLIENT_PING_INTERVAL_AND_MSG),
     None
 );
+impl_ws_client_trait!(BithumbWSClient);
