@@ -40,7 +40,7 @@ impl_candlestick!(GateSpotWSClient);
 
 panic_l3_orderbook!(GateSpotWSClient);
 
-define_client!(
+impl_new_constructor!(
     GateSpotWSClient,
     EXCHANGE_NAME,
     WEBSOCKET_URL,
@@ -49,3 +49,4 @@ define_client!(
     Some(CLIENT_PING_INTERVAL_AND_MSG),
     None
 );
+impl_ws_client_trait!(GateSpotWSClient);
