@@ -125,7 +125,7 @@ impl_candlestick!(ZbgSwapWSClient);
 
 panic_l3_orderbook!(ZbgSwapWSClient);
 
-define_client!(
+impl_new_constructor!(
     ZbgSwapWSClient,
     EXCHANGE_NAME,
     WEBSOCKET_URL,
@@ -134,3 +134,4 @@ define_client!(
     Some(CLIENT_PING_INTERVAL_AND_MSG),
     None
 );
+impl_ws_client_trait!(ZbgSwapWSClient);
