@@ -1,13 +1,16 @@
 macro_rules! gen_test_code {
     ($client:ident, $func_name:ident, $pairs:expr) => {
+        let (tx, rx): (Sender<String>, Receiver<String>) = std::sync::mpsc::channel();
         let mut messages = Vec::<String>::new();
         {
-            let on_msg = Arc::new(Mutex::new(|msg: String| messages.push(msg)));
-            let ws_client = $client::new(on_msg.clone(), None);
+            let ws_client = $client::new(tx, None);
             ws_client.$func_name($pairs);
             ws_client.run(Some(0)); // return immediately once after a normal message
             ws_client.close();
         }
+        for msg in rx {
+            messages.push(msg);
+        }
         assert!(!messages.is_empty());
     };
 }
@@ -16,14 +19,17 @@ macro_rules! gen_test_code {
 #[allow(unused_macros)]
 macro_rules! gen_test_subscribe_candlestick {
     ($client:ident, $symbol_interval_list:expr) => {
+        let (tx, rx): (Sender<String>, Receiver<String>) = std::sync::mpsc::channel();
         let mut messages = Vec::<String>::new();
         {
-            let on_msg = Arc::new(Mutex::new(|msg: String| messages.push(msg)));
-            let ws_client = $client::new(on_msg.clone(), None);
+            let ws_client = $client::new(tx, None);
             ws_client.subscribe_candlestick($symbol_interval_list);
             ws_client.run(Some(0)); // return immediately once after a normal message
             ws_client.close();
         }
+        for msg in rx {
+            messages.push(msg);
+        }
         assert!(!messages.is_empty());
     };
 }
